# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRecordsCategories(BaseModel):
    get_records_categories: Optional[
        List[Optional["GetRecordsCategoriesGetRecordsCategories"]]
    ] = Field(alias="getRecordsCategories")


class GetRecordsCategoriesGetRecordsCategories(BaseModel):
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    items: Optional[List[Optional["GetRecordsCategoriesGetRecordsCategoriesItems"]]]


class GetRecordsCategoriesGetRecordsCategoriesItems(BaseModel):
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    items: Optional[
        List[Optional["GetRecordsCategoriesGetRecordsCategoriesItemsItems"]]
    ]


class GetRecordsCategoriesGetRecordsCategoriesItemsItems(BaseModel):
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    items: Optional[
        List[Optional["GetRecordsCategoriesGetRecordsCategoriesItemsItemsItems"]]
    ]


class GetRecordsCategoriesGetRecordsCategoriesItemsItemsItems(BaseModel):
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    items: Optional[
        List[Optional["GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItems"]]
    ]


class GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItems(BaseModel):
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    items: Optional[
        List[
            Optional[
                "GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItemsItems"
            ]
        ]
    ]


class GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItemsItems(BaseModel):
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")


GetRecordsCategories.model_rebuild()
GetRecordsCategoriesGetRecordsCategories.model_rebuild()
GetRecordsCategoriesGetRecordsCategoriesItems.model_rebuild()
GetRecordsCategoriesGetRecordsCategoriesItemsItems.model_rebuild()
GetRecordsCategoriesGetRecordsCategoriesItemsItemsItems.model_rebuild()
GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItems.model_rebuild()
